[nautilus] general: fix typo



commit 63b48b37d2fb69e30ae3a1ae9c9c67247ba502fd
Author: Carlos Soriano <csoriano gnome org>
Date:   Fri Dec 9 22:35:38 2016 +0100

    general: fix typo
    
    Mis hojos!

 src/nautilus-canvas-dnd.c      |   10 +++++-----
 src/nautilus-dnd.c             |    2 +-
 src/nautilus-dnd.h             |    4 ++--
 src/nautilus-window-slot-dnd.c |    8 ++++----
 4 files changed, 12 insertions(+), 12 deletions(-)
---
diff --git a/src/nautilus-dnd.c b/src/nautilus-dnd.c
index fb5ebec..733811e 100644
--- a/src/nautilus-dnd.c
+++ b/src/nautilus-dnd.c
@@ -72,7 +72,7 @@ nautilus_drag_init (NautilusDragInfo     *drag_info,
                                           NAUTILUS_ICON_DND_TEXT);
     }
 
-    drag_info->drop_occured = FALSE;
+    drag_info->drop_occurred = FALSE;
     drag_info->need_to_destroy = FALSE;
 }
 
diff --git a/src/nautilus-window-slot-dnd.c b/src/nautilus-window-slot-dnd.c
index fbf6c40..b8dd87a 100644
--- a/src/nautilus-window-slot-dnd.c
+++ b/src/nautilus-window-slot-dnd.c
@@ -35,7 +35,7 @@ typedef struct
     gboolean have_data;
     gboolean have_valid_data;
 
-    gboolean drop_occured;
+    gboolean drop_occurred;
 
     unsigned int info;
     union
@@ -326,7 +326,7 @@ out:
     drag_info->have_data = FALSE;
     drag_info->have_valid_data = FALSE;
 
-    drag_info->drop_occured = FALSE;
+    drag_info->drop_occurred = FALSE;
 }
 
 static void
@@ -357,7 +357,7 @@ slot_proxy_drag_drop (GtkWidget      *widget,
     drag_info = user_data;
     g_assert (!drag_info->have_data);
 
-    drag_info->drop_occured = TRUE;
+    drag_info->drop_occurred = TRUE;
 
     target = gtk_drag_dest_find_target (widget, context, NULL);
     gtk_drag_get_data (widget, context, target, time);
@@ -519,7 +519,7 @@ slot_proxy_drag_data_received (GtkWidget        *widget,
         drag_info->have_valid_data = drag_info->data.selection_data != NULL;
     }
 
-    if (drag_info->drop_occured)
+    if (drag_info->drop_occurred)
     {
         slot_proxy_handle_drop (widget, context, time, drag_info);
     }


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/nautilus-canvas-dnd.c b/src/nautilus-canvas-dnd.c
index 5b957e0..d01c876 100644
--- a/src/nautilus-canvas-dnd.c
+++ b/src/nautilus-canvas-dnd.c
@@ -561,7 +561,7 @@ get_data_on_first_target_we_support (GtkWidget      *widget,
         /* Don't get_data for destructive ops */
         if ((info == NAUTILUS_ICON_DND_ROOTWINDOW_DROP ||
              info == NAUTILUS_ICON_DND_XDNDDIRECTSAVE) &&
-            !drag_info->drop_occured)
+            !drag_info->drop_occurred)
         {
             /* We can't call get_data here, because that would
              *  make the source execute the rootwin action or the direct save */
@@ -1742,11 +1742,11 @@ drag_drop_callback (GtkWidget      *widget,
     dnd_info = NAUTILUS_CANVAS_CONTAINER (widget)->details->dnd_info;
 
     /* tell the drag_data_received callback that
      *  the drop occured and that it can actually
      *  process the actions.
      *  make sure it is going to be called at least once.
      */
-    dnd_info->drag_info.drop_occured = TRUE;
+    dnd_info->drag_info.drop_occurred = TRUE;
 
     get_data_on_first_target_we_support (widget, context, time, x, y);
 
@@ -1840,7 +1840,7 @@ drag_data_received_callback (GtkWidget        *widget,
     /* this is the second use case of this callback.
      * we have to do the actual work for the drop.
      */
-    if (drag_info->drop_occured)
+    if (drag_info->drop_occurred)
     {
         success = FALSE;
         switch (info)
@@ -1952,7 +1952,7 @@ drag_data_received_callback (GtkWidget        *widget,
         set_drop_target (NAUTILUS_CANVAS_CONTAINER (widget), NULL);
 
         /* reinitialise it for the next dnd */
-        drag_info->drop_occured = FALSE;
+        drag_info->drop_occurred = FALSE;
     }
 }
 
@@ -1742,11 +1742,11 @@ drag_drop_callback (GtkWidget      *widget,
 
     /* tell the drag_data_received callback that
-     *  the drop occured and that it can actually
+     *  the drop occurred and that it can actually
      *  process the actions.
      *  make sure it is going to be called at least once.
diff --git a/src/nautilus-dnd.h b/src/nautilus-dnd.h
index 35872ae..d4d3bb8 100644
--- a/src/nautilus-dnd.h
+++ b/src/nautilus-dnd.h
@@ -64,8 +64,8 @@ typedef struct {
          * come from another nautilus process, like the desktop. */
         NautilusFileListHandle *file_list_info_handler;
 
-       /* has the drop occured ? */
-       gboolean drop_occured;
+       /* has the drop occurred ? */
+       gboolean drop_occurred;
 
        /* whether or not need to clean up the previous dnd data */
        gboolean need_to_destroy;